@@ -1,3 +1,5 @@
+
+from io import TextIOWrapper
 import os
 import shutil
 import click
@@ -10,18 +12,17 @@ def cli():  # pragma: no cover
 
 
 @click.command()
-@click.argument("file")
-@click.option("-O", "--outdir", default="./out/", help="The out directory for the generated CSVs")
-def generate(file: str, outdir: str):
-    if not os.path.isfile(file):
-        raise click.UsageError(f"File does not exist: '{file}'")
-
+@click.argument("file", type=click.File("r"))
+@click.option("-O", "--outdir", default="out", help="The directory where the generated CSVs will be stored", type=click.Path(file_okay=False, writable=True), show_default=True)
+def generate(file: TextIOWrapper, outdir: str):
     # check if the 'out'-directory already exists
     if os.path.isdir(outdir):
+        # TODO: reenable confirmation
         click.confirm(f"The output directory '{outdir}' and ALL ITS CONTENTS will be REMOVED! Continue?",
                       default=False, abort=True, prompt_suffix=": ", show_default=True, err=False)
-
+        # delete the existing directory
         shutil.rmtree(outdir)
+
     # create the directory
     try:
         os.mkdir(outdir)
